@@ -21,7 +21,7 @@
 
 QT_BEGIN_NAMESPACE
 
-class Q_CHARTS_PRIVATE_EXPORT EditableAxisLabel : public QGraphicsTextItem
+class Q_CHARTS_EXPORT EditableAxisLabel : public QGraphicsTextItem
 {
     Q_OBJECT
 public:
